import { Injectable } from '@nestjs/common'
import { CreateTrainDto } from './dto/create-train.dto'
import { UpdateTrainDto } from './dto/update-train.dto'
import { PrismaService } from 'src/prisma/prisma.service'
import { TrainTrip } from '@prisma/client'
import { QueryPaginationDto } from 'src/common/dto/pagination-query.dto'
import { paginate } from 'src/common/utils/pagination.utils'

@Injectable()
export class TrainsService {
  constructor(private prisma: PrismaService) { }

  async create(createTrainDto: CreateTrainDto): Promise<TrainTrip> {
    return await this.prisma.trainTrip.create({ data: createTrainDto })
  }

  async findAll(queryPagination?: QueryPaginationDto): Promise<[TrainTrip[], number]> {
    return [
      await this.prisma.trainTrip.findMany({
        ...paginate(queryPagination),
      }),
      await this.prisma.challenge.count(),
    ]
  }

  async findOne(id: string): Promise<TrainTrip> {
    return await this.prisma.trainTrip.findUnique({
      where: { id },
    })
  }

  async update(id: string, updateTrainDto: UpdateTrainDto): Promise<TrainTrip> {
    return await this.prisma.trainTrip.update({
      where: { id },
      data: updateTrainDto,
    })
  }

  async remove(id: string): Promise<TrainTrip> {
    return await this.prisma.trainTrip.delete({
      where: { id },
    })
  }
}
